Index: chrome/browser/ui/cocoa/content_settings/content_setting_bubble_cocoa_unittest.mm |
diff --git a/chrome/browser/ui/cocoa/content_settings/content_setting_bubble_cocoa_unittest.mm b/chrome/browser/ui/cocoa/content_settings/content_setting_bubble_cocoa_unittest.mm |
index f69ece544723423f0958e4246cddddb6bfbf0fe1..79eb0580cce7352686c0ced01c68a385bb0c2937 100644 |
--- a/chrome/browser/ui/cocoa/content_settings/content_setting_bubble_cocoa_unittest.mm |
+++ b/chrome/browser/ui/cocoa/content_settings/content_setting_bubble_cocoa_unittest.mm |
@@ -56,8 +56,11 @@ ContentSettingBubbleControllerTest::~ContentSettingBubbleControllerTest() { |
TEST_F(ContentSettingBubbleControllerTest, Init) { |
for (int i = 0; i < CONTENT_SETTINGS_NUM_TYPES; ++i) { |
if (i == CONTENT_SETTINGS_TYPE_NOTIFICATIONS || |
- i == CONTENT_SETTINGS_TYPE_INTENTS) |
- continue; // Notifications and web intents have no bubble. |
+ i == CONTENT_SETTINGS_TYPE_INTENTS || |
+ i == CONTENT_SETTINGS_TYPE_AUTO_SELECT_CERTIFICATE) { |
+ // Notifications, web intents and auto select certificate have no bubble. |
+ continue; |
+ } |
ContentSettingsType settingsType = static_cast<ContentSettingsType>(i); |